@@ -1,23 +1,20 @@
 #!/bin/env python
 
 import pytest
+from hdfstream import RemoteDirectory
 
 @pytest.mark.vcr
-def test_root_listing():
+def test_root_listing(server_url):
 
     import hdfstream
-    root = hdfstream.open("https://dataweb.cosma.dur.ac.uk:8443/hdfstream", "/")
-    assert len(root) == 2
-    assert "EAGLE" in root
-    assert "SWIFT" in root
-    assert len(root.files) == 0
-    assert len(root.directories) == 2
+    root = hdfstream.open(server_url, "/")
+    assert isinstance(root, RemoteDirectory)
 
 @pytest.mark.vcr
-def test_eagle_dir_listing():
+def test_eagle_dir_listing(server_url):
 
     import hdfstream
-    eagle_dir = hdfstream.open("https://dataweb.cosma.dur.ac.uk:8443/hdfstream", "/EAGLE")
+    eagle_dir = hdfstream.open(server_url, "/EAGLE")
     fm_dir = eagle_dir["Fiducial_models"]
     assert len(fm_dir) == 9
     expected_files = set(["description.md", "labels.msgpack"])
@@ -29,10 +26,10 @@ def test_eagle_dir_listing():
     assert set(fm_dir.directories.keys()) == expected_dirs
 
 @pytest.mark.vcr
-def test_eagle_file_listing():
+def test_eagle_file_listing(server_url):
 
     import hdfstream
-    snap_dir = hdfstream.open("https://dataweb.cosma.dur.ac.uk:8443/hdfstream",
+    snap_dir = hdfstream.open(server_url,
                               "/EAGLE/Fiducial_models/RefL0012N0188/snapshot_028_z000p000")
     expected_files = set([f"snap_028_z000p000.{i}.hdf5" for i in range(16)])
     assert set(snap_dir.keys()) == expected_files
